..
      Copyright 2014-2015 OpenStack Foundation
      All Rights Reserved.

      Licensed under the Apache License, Version 2.0 (the "License"); you may
      not use this file except in compliance with the License. You may obtain
      a copy of the License at

          http://www.apache.org/licenses/LICENSE-2.0

      Unless required by applicable law or agreed to in writing, software
      distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
      WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
      License for the specific language governing permissions and limitations
      under the License.

=================================
Welcome to Kolla's documentation!
=================================

Kolla's mission is to provide production-ready containers and deployment tools
for operating OpenStack clouds.

Related Projects
================

This documentation is for the Kolla container images.

`Kolla-ansible <https://docs.openstack.org/kolla-ansible/latest/>`_ is a
subproject of Kolla that deploys the Kolla container images using Ansible.

`Kayobe <https://docs.openstack.org/kayobe/latest/>`_ is a subproject of Kolla
that uses Kolla Ansible and Bifrost to deploy an OpenStack control plane to
bare metal.

Site Notes
==========

This documentation is continually updated and may not represent the state of
the project at any specific prior release. To access documentation for a
previous release of kolla, choose one of the OpenStack release names on
the right of the title.

Release Notes
=============

The release notes for the project can be found here:
https://docs.openstack.org/releasenotes/kolla/

Administrator Guide
===================

.. toctree::
   :maxdepth: 2

   admin/index

Support Matrix
==============

.. toctree::
   :maxdepth: 2

   support_matrix

Contributor Guide
=================

.. toctree::
   :maxdepth: 2

   contributor/index
